@@ -1,4 +1,4 @@
-from pyspark.sql.types import StringType, IntegerType
+from pyspark.sql.types import LongType
 from pyspark.sql.dataframe import DataFrame as SparkDF
 from pyspark.sql import functions as f
 from pandas import DataFrame as PandasDF
@@ -120,9 +120,9 @@ def make_dataframe_hashable(data):
 			"""
 			return [_hash_int(x) for column, x in row.asDict().items()]
 
-		spark_int_data = spark_compressed.rdd.map(_map_function,).toDF(spark_compressed.columns)
+		spark_int_data = spark_compressed.rdd.map(_map_function).toDF(spark_compressed.columns)
 
-		@f.udf(IntegerType())
+		@f.udf(LongType())
 		def spark_bitwise_xor(numbers):
 			return reduce(lambda x, y: x ^ y, numbers)
 
